@@ -5,8 +5,10 @@ import os
 import sys
 
 from ICCProfile import ICCProfile
+from argyll_cgats import extract_device_gray_primaries
 from config import (enc, get_data_path, get_verified_path, getcfg, hascfg,
 					profile_ext, setcfg)
+from debughelpers import Error
 from log import log, safe_print
 from meta import name as appname
 from options import debug
@@ -15,12 +17,13 @@ from util_io import Files
 from util_os import waccess
 from util_str import safe_str
 from worker import Error, FilteredStream, LineBufferedStream, show_result_dialog
+import CGATS
 import ICCProfile as ICCP
 import colormath
 import config
 import localization as lang
 import worker
-from wxwindows import BaseApp, BaseFrame, FileDrop, InfoDialog, wx
+from wxwindows import BaseApp, BaseFrame, ConfirmDialog, FileDrop, InfoDialog, wx
 from wxfixes import TempXmlResource
 from wxLUT3DFrame import LUT3DFrame
 import floatspin
@@ -56,6 +59,8 @@ class SynthICCFrame(BaseFrame):
 			self.res.LoadFrame(self, parent, "synthiccframe")
 		self.init()
 		self.Bind(wx.EVT_CLOSE, self.OnClose)
+		if sys.platform == "win32":
+			self.Bind(wx.EVT_SIZE, self.OnSize)
 		
 		self.SetIcons(config.get_icon_bundle([256, 48, 32, 16],
 											 appname + "-synthprofile"))
@@ -70,12 +75,15 @@ class SynthICCFrame(BaseFrame):
 		presets = [""] + sorted(colormath.rgb_spaces.keys())
 		self.preset_ctrl.SetItems(presets)
 
+		self.set_default_cat()
+
 		self.worker = worker.Worker(self)
 
 		# Drop targets
 		self.droptarget = FileDrop(self)
 		self.droptarget.drophandlers = {".icc": self.drop_handler,
-										".icm": self.drop_handler}
+										".icm": self.drop_handler,
+										".ti3": self.drop_handler}
 		self.panel.SetDropTarget(self.droptarget)
 
 		# Bind event handlers
@@ -92,6 +100,8 @@ class SynthICCFrame(BaseFrame):
 						  getattr(self, "%s_%s" % (color, component)))
 		self.black_point_cb.Bind(wx.EVT_CHECKBOX,
 								 self.black_point_enable_handler)
+		self.chromatic_adaptation_btn.Bind(wx.EVT_BUTTON,
+										   self.chromatic_adaptation_btn_handler)
 		self.trc_ctrl.Bind(wx.EVT_CHOICE, self.trc_ctrl_handler)
 		self.trc_gamma_ctrl.Bind(wx.EVT_COMBOBOX, self.trc_gamma_ctrl_handler)
 		self.trc_gamma_ctrl.Bind(wx.EVT_KILL_FOCUS, self.trc_gamma_ctrl_handler)
@@ -112,20 +122,24 @@ class SynthICCFrame(BaseFrame):
 		self.save_as_btn.Bind(wx.EVT_BUTTON, self.save_as_btn_handler)
 
 		self.save_as_btn.SetDefault()
-		self.save_as_btn.Disable()
 		
 		self.setup_language()
 		
 		self.update_controls()
 		self.update_layout()
+		if self.panel.VirtualSize[0] > self.panel.Size[0]:
+			scrollrate_x = 2
+		else:
+			scrollrate_x = 0
+		self.panel.SetScrollRate(scrollrate_x, 2)
 		
 		self.save_btn.Hide()
 		
 		config.defaults.update({
 			"position.synthiccframe.x": self.GetDisplay().ClientArea[0] + 40,
 			"position.synthiccframe.y": self.GetDisplay().ClientArea[1] + 60,
-			"size.synthiccframe.w": self.GetMinSize()[0],
-			"size.synthiccframe.h": self.GetMinSize()[1]})
+			"size.synthiccframe.w": self.ClientSize[0],
+			"size.synthiccframe.h": self.ClientSize[1]})
 
 		if (hascfg("position.synthiccframe.x") and
 			hascfg("position.synthiccframe.y") and
@@ -137,6 +151,10 @@ class SynthICCFrame(BaseFrame):
 								 int(getcfg("size.synthiccframe.h")))
 		else:
 			self.Center()
+
+	def OnSize(self, event):
+		event.Skip()
+		self.Refresh()  # Prevents distorted drawing under Windows
 	
 	def OnClose(self, event=None):
 		if sys.platform == "darwin" or debug: self.focus_handler(event)
@@ -145,8 +163,8 @@ class SynthICCFrame(BaseFrame):
 			x, y = self.GetScreenPosition()
 			setcfg("position.synthiccframe.x", x)
 			setcfg("position.synthiccframe.y", y)
-			setcfg("size.synthiccframe.w", self.GetSize()[0])
-			setcfg("size.synthiccframe.h", self.GetSize()[1])
+			setcfg("size.synthiccframe.w", self.ClientSize[0])
+			setcfg("size.synthiccframe.h", self.ClientSize[1])
 		if self.Parent:
 			config.writecfg()
 		else:
@@ -240,8 +258,7 @@ class SynthICCFrame(BaseFrame):
 					for i in xrange(3):
 						getattr(self, "black_%s" % "XYZ"[i]).SetValue(0)
 					break
-		for i, v in enumerate(colormath.XYZ2xyY(*XYZ)[:2]):
-			getattr(self, "black_%s" % "xy"[i]).SetValue(v)
+		self.parse_XYZ("black")
 
 	def black_xy_ctrl_handler(self, event):
 		# Black Y scaled to 0..1 range
@@ -260,17 +277,96 @@ class SynthICCFrame(BaseFrame):
 	
 	def blue_xy_ctrl_handler(self, event):
 		self.parse_xy("blue")
+
+	def chromatic_adaptation_btn_handler(self, event):
+		scale = getcfg("app.dpi") / config.get_default_dpi()
+		if scale < 1:
+			scale = 1
+		dlg = ConfirmDialog(self, title=lang.getstr("chromatic_adaptation"),
+							msg=lang.getstr("whitepoint.xy"),
+							ok=lang.getstr("apply"),
+							cancel=lang.getstr("cancel"))
+		sizer = wx.BoxSizer(wx.HORIZONTAL)
+		dlg.sizer3.Add(sizer, 0, flag=wx.TOP | wx.ALIGN_LEFT,
+					   border=8)
+		x_ctrl = floatspin.FloatSpin(dlg, -1, size=(75 * scale, -1),
+									 min_val=0.00001, max_val=1,
+									 increment=0.00001,
+									 value=self.white_x.GetValue())
+		sizer.Add(x_ctrl, 0, flag=wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+				  border=4)
+		sizer.Add(wx.StaticText(dlg, -1, u"x"), 0,
+								flag=wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+								border=12)
+		y_ctrl = floatspin.FloatSpin(dlg, -1, size=(75 * scale, -1),
+									 min_val=0.00001, max_val=1,
+									 increment=0.00001,
+									 value=self.white_y.GetValue())
+		sizer.Add(y_ctrl, 0, flag=wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+				  border=4)
+		sizer.Add(wx.StaticText(dlg, -1, u"y"), 0,
+								flag=wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+								border=12)
+		dlg.sizer3.Add(wx.StaticText(dlg, -1,
+									 lang.getstr("chromatic_adaptation_transform")),
+					   0, flag=wx.TOP | wx.ALIGN_LEFT, border=12)
+		if getcfg("show_advanced_options"):
+			# Only offer those that seem suitable in an ICC workflow
+			# (i.e. blue primary not too far from default Bradford to
+			# prevent 'blue turns purple' problems)
+			cat_choices = ['Bradford', 'CAT02BS']
+		else:
+			cat_choices = ["Bradford"]
+		cat_choices_ab = OrderedDict(get_mapping(((k, k) for k in
+												  colormath.cat_matrices),
+												 cat_choices))
+		cat_choices_ba = OrderedDict((v, k) for k, v in cat_choices_ab.iteritems())
+		cat_ctrl = wx.Choice(dlg, -1, choices=cat_choices_ab.values())
+		cat_ctrl.SetStringSelection(cat_choices_ab[self.cat])
+		dlg.sizer3.Add(cat_ctrl, 0, flag=wx.TOP | wx.ALIGN_LEFT, border=8)
+		dlg.sizer0.SetSizeHints(dlg)
+		dlg.sizer0.Layout()
+		result = dlg.ShowModal()
+		x = x_ctrl.GetValue()
+		y = y_ctrl.GetValue()
+		cat = cat_choices_ba[cat_ctrl.GetStringSelection()]
+		dlg.Destroy()
+		if result != wx.ID_OK:
+			return
+		wp_src = [getattr(self, "white_" + component).GetValue()
+				  for component in "XYZ"]
+		wp_tgt = colormath.xyY2XYZ(x, y)
+		self.cat = cat
+		for color in ("red", "green", "blue", "white", "black"):
+			ctrls = [getattr(self, "%s_%s" % (color, component))
+					 for component in "XYZ"]
+			X, Y, Z = (ctrl.GetValue() for ctrl in ctrls)
+			XYZa = colormath.adapt(X, Y, Z, wp_src, wp_tgt, cat)
+			for i, ctrl in enumerate(ctrls):
+				ctrl.SetValue(XYZa[i])
+			self.parse_XYZ(color, False)
 	
 	def colorspace_ctrl_handler(self, event):
+		self.Freeze()
 		show = bool(self.colorspace_rgb_ctrl.Value)
 		for color in ("red", "green", "blue"):
 			getattr(self, "label_%s" % color).Show(show)
 			for component in "XYZxy":
 				getattr(self, "%s_%s" % (color, component)).Show(show)
-		self.enable_save_as_btn()
+		self.enable_btns()
 		self.update_layout()
+		self.Thaw()
 	
 	def drop_handler(self, path):
+		""" File dropped """
+		fn, ext = os.path.splitext(path)
+		if ext.lower() == ".ti3":
+			self.ti3_drop_handler(path)
+		else:
+			self.icc_drop_handler(path)
+
+	def icc_drop_handler(self, path):
+		""" ICC profile dropped """
 		try:
 			profile = ICCP.ICCProfile(path)
 		except (IOError, ICCP.ICCProfileInvalidError), exception:
@@ -297,49 +393,105 @@ class SynthICCFrame(BaseFrame):
 			except Exception, exception:
 				show_result_dialog(exception, self)
 			else:
-				self.panel.Freeze()
-				for ctrl, value in [(self.colorspace_rgb_ctrl,
-									 profile.colorSpace == "RGB"),
-									(self.colorspace_gray_ctrl,
-									 profile.colorSpace == "GRAY")]:
-					ctrl.SetValue(value)
-				self.colorspace_ctrl_handler(None)
 				if "lumi" in profile.tags:
 					luminance = profile.tags.lumi.Y
 				else:
 					luminance = 100
-				setcfg("synthprofile.luminance", luminance)
-				self.luminance_ctrl.SetValue(luminance)
-				for i, color in enumerate(("white", "black")):
-					for j, component in enumerate("XYZ"):
-						getattr(self, "%s_%s" %
-								(color, component)).SetValue(colors[i][j] /
-															 colors[0][1] * 100)
-					self.parse_XYZ(color)
-				for i, color in enumerate(("red", "green", "blue")):
-					xyY = colormath.XYZ2xyY(*colors[2 + i])
-					for j, component in enumerate("xy"):
-						getattr(self, "%s_%s" %
-								(color, component)).SetValue(xyY[j])
-				self.parse_xy(None)
-				self.black_XYZ_ctrl_handler(None)
-				trc = ICCP.CurveType(profile=profile)
-				for XYZ in colors[5:]:
-					trc.append(XYZ[1] / colors[0][1] * 65535)
-				transfer_function = trc.get_transfer_function(outoffset=1.0)
-				if transfer_function and transfer_function[1] >= .95:
-					# Use detected transfer function
-					gamma = transfer_function[0][1]
+				if (not colors[1][1] and
+					isinstance(profile.tags.get("targ"), ICCP.Text)):
+					# The profile may not reflect the actual black point.
+					# Get it from the embedded TI3 instead if zero from lookup.
+					XYZbp = profile.get_chardata_bkpt(True)
+					if XYZbp:
+						# Use wtpt chromaticity
+						colors[1] = [v * XYZbp[1] for v in colors[0]]
+				self.set_colors(colors, luminance, profile.colorSpace)
+
+	def set_colors(self, colors, luminance, colorspace):
+		""" Set controls according to args """
+		self.panel.Freeze()
+		for ctrl, value in [(self.colorspace_rgb_ctrl,
+							 colorspace == "RGB"),
+							(self.colorspace_gray_ctrl,
+							 colorspace == "GRAY")]:
+			ctrl.SetValue(value)
+		self.colorspace_ctrl_handler(None)
+		setcfg("synthprofile.luminance", luminance)
+		self.luminance_ctrl.SetValue(luminance)
+		for i, color in enumerate(("white", "black")):
+			for j, component in enumerate("XYZ"):
+				getattr(self, "%s_%s" %
+						(color, component)).SetValue(colors[i][j] /
+													 colors[0][1] * 100)
+			self.parse_XYZ(color)
+		for i, color in enumerate(("red", "green", "blue")):
+			xyY = colormath.XYZ2xyY(*colors[2 + i])
+			for j, component in enumerate("xy"):
+				getattr(self, "%s_%s" %
+						(color, component)).SetValue(xyY[j])
+		self.parse_xy(None)
+		self.black_XYZ_ctrl_handler(None)
+		if len(colors[5:]) > 2:
+			trc = ICCP.CurveType()
+			for XYZ in colors[5:]:
+				trc.append(XYZ[1] / colors[0][1] * 65535)
+			transfer_function = trc.get_transfer_function(outoffset=1.0)
+			if transfer_function and transfer_function[1] >= .95:
+				# Use detected transfer function
+				gamma = transfer_function[0][1]
+			else:
+				# Use 50% gamma value
+				gamma = math.log(colors[132][1]) / math.log(128.0 / 255)
+			self.set_trc(round(gamma, 2))
+			setcfg("synthprofile.trc_gamma_type", "g")
+			self.trc_gamma_type_ctrl.SetSelection(self.trc_gamma_types_ba["g"])
+		self.panel.Thaw()
+
+	def ti3_drop_handler(self, path):
+		""" TI3 file dropped """
+		try:
+			ti3 = CGATS.CGATS(path)
+		except (IOError, CGATS.CGATSInvalidError), exception:
+			show_result_dialog(Error(lang.getstr("error.measurement.file_invalid",
+												 path)), self)
+		else:
+			ti3[0].normalize_to_y_100()
+			rgb = [(100, 100, 100), (0, 0, 0), (100, 0, 0), (0, 100, 0), (0, 0, 100)]
+			colors = []
+			for R, G, B in rgb:
+				result = ti3.queryi1({"RGB_R": R, "RGB_G": G, "RGB_B": B})
+				if result:
+					color = []
+					for component in "XYZ":
+						label = "XYZ_" + component
+						if label in result:
+							color.append(result[label])
+				if not result or len(color) < 3:
+					color = (0, 0, 0)
+				colors.append(color)
+			try:
+				(ti3_extracted,
+				 RGB_XYZ_extracted,
+				 RGB_XYZ_remaining) = extract_device_gray_primaries(ti3)
+			except Error, exception:
+				show_result_dialog(exception, self)
+			else:
+				RGB_XYZ_extracted.sort()
+				colors.extend(RGB_XYZ_extracted.values())
+				luminance = ti3.queryv1("LUMINANCE_XYZ_CDM2")
+				if luminance:
+					try:
+						luminance = float(luminance.split()[1])
+					except (TypeError, ValueError):
+						luminance = 100
 				else:
-					# Use 50% gamma value
-					gamma = math.log(colors[132][1]) / math.log(128.0 / 255)
-				self.set_trc(round(gamma, 2))
-				setcfg("synthprofile.trc_gamma_type", "g")
-				self.trc_gamma_type_ctrl.SetSelection(self.trc_gamma_types_ba["g"])
-				self.panel.Thaw()
+					luminance = 100
+				self.set_colors(colors, luminance, "RGB")
 	
-	def enable_save_as_btn(self):
-		self.save_as_btn.Enable(bool(self.get_XYZ()))
+	def enable_btns(self):
+		enable = bool(self.get_XYZ())
+		self.save_as_btn.Enable(enable)
+		self.chromatic_adaptation_btn.Enable(enable)
 	
 	def get_XYZ(self):
 		""" Get XYZ in 0..1 range """
@@ -371,11 +523,16 @@ class SynthICCFrame(BaseFrame):
 	def luminance_ctrl_handler(self, event):
 		v = self.luminance_ctrl.GetValue()
 		setcfg("synthprofile.luminance", v)
+		target_peak = v
+		maxmll = self.lut3d_hdr_maxmll_ctrl.GetValue()
+		if maxmll < target_peak:
+			setcfg("3dlut.hdr_maxmll", target_peak)
+		self.lut3d_hdr_maxmll_ctrl.SetRange(target_peak, 10000)
 		self.lut3d_set_option("3dlut.hdr_peak_luminance", v)
 		self.black_luminance_ctrl_handler(event)
 	
-	def parse_XYZ(self, name, set_blackpoint=False):
-		if not set_blackpoint:
+	def parse_XYZ(self, name, set_blackpoint=None):
+		if set_blackpoint is None:
 			set_blackpoint = not self.black_point_cb.Value
 		if not self._updating_ctrls:
 			self.preset_ctrl.SetSelection(0)
@@ -389,12 +546,18 @@ class SynthICCFrame(BaseFrame):
 			if name == "white" and set_blackpoint:
 				getattr(self, "black_%s" % (component)).SetValue(v * black_Y)
 		if "X" in XYZ and "Y" in XYZ and "Z" in XYZ:
-			xyY = colormath.XYZ2xyY(XYZ["X"], XYZ["Y"], XYZ["Z"])
+			if XYZ["X"] + XYZ["Y"] + XYZ["Z"] == 0:
+				# Set black chromaticity to white chromaticity if XYZ is 0
+				xyY = []
+				for i, component in enumerate("xy"):
+					xyY.append(getattr(self, "white_%s" % component).GetValue())
+			else:
+				xyY = colormath.XYZ2xyY(XYZ["X"], XYZ["Y"], XYZ["Z"])
 			for i, component in enumerate("xy"):
 				getattr(self, "%s_%s" % (name, component)).SetValue(xyY[i])
 				if name == "white" and set_blackpoint:
 					getattr(self, "black_%s" % (component)).SetValue(xyY[i])
-		self.enable_save_as_btn()
+		self.enable_btns()
 	
 	def parse_xy(self, name=None, set_blackpoint=False):
 		if not set_blackpoint:
@@ -447,11 +610,12 @@ class SynthICCFrame(BaseFrame):
 			for i, component in enumerate("XYZ"):
 				getattr(self, "%s_%s" %
 						(color, component)).SetValue(XYZ[color[0]][i] * 100)
-		self.enable_save_as_btn()
+		self.enable_btns()
 	
 	def preset_ctrl_handler(self, event):
 		preset_name = self.preset_ctrl.GetStringSelection()
 		if preset_name:
+			self.set_default_cat()
 			gamma, white, red, green, blue = colormath.rgb_spaces[preset_name]
 			white = colormath.get_whitepoint(white)
 			self._updating_ctrls = True
@@ -493,6 +657,9 @@ class SynthICCFrame(BaseFrame):
 			return "ok"
 		return "invalid"
 
+	def set_default_cat(self):
+		self.cat = "Bradford"
+
 	def set_trc(self, gamma):
 		if gamma == -1023:
 			# DICOM
@@ -526,7 +693,7 @@ class SynthICCFrame(BaseFrame):
 		self.update_trc_controls()
 	
 	def profile_name_ctrl_handler(self, event):
-		self.enable_save_as_btn()
+		self.enable_btns()
 	
 	def red_XYZ_ctrl_handler(self, event):
 		self.parse_XYZ("red")
@@ -631,7 +798,9 @@ class SynthICCFrame(BaseFrame):
 											   (XYZ["wX"], XYZ["wY"], XYZ["wZ"]),
 											   1.0,
 											   "",
-											   getcfg("copyright"))
+											   getcfg("copyright"),
+											   cat=self.cat,
+											   profile_class=profile_class)
 			black = colormath.adapt(XYZ["kX"], XYZ["kY"], XYZ["kZ"], white)
 			profile.tags.rTRC = ICCP.CurveType(profile=profile)
 			profile.tags.gTRC = ICCP.CurveType(profile=profile)
@@ -640,12 +809,17 @@ class SynthICCFrame(BaseFrame):
 		else:
 			# Grayscale profile
 			profile = ICCP.ICCProfile()
+			# Profile class
+			profile.profileClass = profile_class
+			if (not ICCP.s15f16_is_equal((XYZ["wX"], XYZ["wY"], XYZ["wZ"]),
+										 colormath.get_whitepoint("D50")) and
+				(profile.profileClass not in ("mntr", "prtr") or
+				 colormath.is_similar_matrix(colormath.get_cat_matrix(self.cat),
+										     colormath.get_cat_matrix("Bradford")))):
+				profile.version = 2.2  # Match ArgyllCMS
 			profile.colorSpace = "GRAY"
 			profile.setCopyright(getcfg("copyright"))
-			profile.tags.wtpt = ICCP.XYZType()
-			(profile.tags.wtpt.X,
-			 profile.tags.wtpt.Y,
-			 profile.tags.wtpt.Z) = (XYZ["wX"], XYZ["wY"], XYZ["wZ"])
+			profile.set_wtpt((XYZ["wX"], XYZ["wY"], XYZ["wZ"]), self.cat)
 			black = [XYZ["wY"] * (getcfg("synthprofile.black_luminance") /
 								  getcfg("synthprofile.luminance"))] * 3
 			profile.tags.kTRC = ICCP.CurveType(profile=profile)
@@ -737,7 +911,8 @@ class SynthICCFrame(BaseFrame):
 						clutres=clutres, sat=getcfg("3dlut.hdr_sat"),
 						hue=getcfg("3dlut.hdr_hue"),
 						generate_B2A=trc == -2, worker=self.worker,
-						logfile=logfiles)
+						logfile=logfiles,
+						cat=self.cat)
 					profile.tags.A2B0 = hdr_clut_profile.tags.A2B0
 					if trc == -2:
 						# HLG
@@ -792,8 +967,6 @@ class SynthICCFrame(BaseFrame):
 			(profile.tags[tagname].X,
 			 profile.tags[tagname].Y,
 			 profile.tags[tagname].Z) = X, Y, Z
-		# Profile class
-		profile.profileClass = profile_class
 		# Technology type
 		if tech:
 			profile.tags.tech = ICCP.SignatureType("sig \0\0\0\0" +
@@ -903,8 +1076,6 @@ class SynthICCFrame(BaseFrame):
 		self.trc_gamma_ctrl.SetValue(str(getcfg("synthprofile.trc_gamma")))
 		self.trc_gamma_ctrl.Show(i in (0, 5))
 		self.trc_gamma_type_ctrl.SetSelection(self.trc_gamma_types_ba[getcfg("synthprofile.trc_gamma_type")])
-		self.panel.GetSizer().Layout()
-		self.panel.Thaw()
 		if i in (0, 5, 7, 8):
 			# Gamma, BT.1886, SMPTE 2084 (PQ)
 			outoffset = int(getcfg("synthprofile.trc_output_offset") * 100)
@@ -912,8 +1083,17 @@ class SynthICCFrame(BaseFrame):
 			outoffset = 100
 		self.black_output_offset_ctrl.SetValue(outoffset)
 		self.black_output_offset_intctrl.SetValue(outoffset)
+		target_peak = getcfg("synthprofile.luminance")
+		maxmll = getcfg("3dlut.hdr_maxmll")
+		# Don't allow maxmll < target peak. Technically this restriction does
+		# not exist, but practically maxmll < target peak doesn't make sense.
+		if maxmll < target_peak:
+			maxmll = target_peak
+			setcfg("3dlut.hdr_maxmll", maxmll)
+		self.lut3d_hdr_maxmll_ctrl.SetRange(target_peak, 10000)
+		self.luminance_ctrl.SetValue(target_peak)
 		self.lut3d_hdr_minmll_ctrl.SetValue(getcfg("3dlut.hdr_minmll"))
-		self.lut3d_hdr_maxmll_ctrl.SetValue(getcfg("3dlut.hdr_maxmll"))
+		self.lut3d_hdr_maxmll_ctrl.SetValue(maxmll)
 		self.lut3d_hdr_maxmll_alt_clip_cb.SetValue(not bool(getcfg("3dlut.hdr_maxmll_alt_clip")))
 		self.lut3d_hdr_sat_ctrl.SetValue(int(round(getcfg("3dlut.hdr_sat") * 100)))
 		self.lut3d_hdr_update_sat_val()
@@ -935,9 +1115,9 @@ class SynthICCFrame(BaseFrame):
 		self.lut3d_hdr_diffuse_white_txt.Show(i == 8)  # SMPTE 2084 (PQ)
 		self.lut3d_hdr_diffuse_white_txt_label.Show(i == 8)  # SMPTE 2084 (PQ)
 		sizer = self.lut3d_hdr_sat_ctrl.ContainingSizer
-		sizer.ShowItems(i in (7, 8))  # SMPTE 2084 (PQ)
+		sizer.ShowItems(i == 8)  # SMPTE 2084 (PQ)
 		sizer = self.lut3d_hdr_hue_ctrl.ContainingSizer
-		sizer.ShowItems(i in (7, 8))  # SMPTE 2084 (PQ)
+		sizer.ShowItems(i == 8)  # SMPTE 2084 (PQ)
 		self.lut3d_hdr_ambient_luminance_label.Show(i == 2)  # HLG
 		self.lut3d_hdr_ambient_luminance_ctrl.Show(i == 2)  # HLG
 		self.lut3d_hdr_ambient_luminance_ctrl_label.Show(i == 2)  # HLG
@@ -955,6 +1135,8 @@ class SynthICCFrame(BaseFrame):
 			self.profile_class_ctrl.SetStringSelection(self.profile_classes["mntr"])
 			self.tech_ctrl.SetStringSelection(self.tech[""])
 			self.ciis_ctrl.SetStringSelection(self.ciis[""])
+		self.panel.GetSizer().Layout()
+		self.panel.Thaw()
 	
 	def white_XYZ_ctrl_handler(self, event):
 		self.parse_XYZ("white")
